configs/image_picker_configs library
Classes
- ImagePickerConfigs
- Global configuration for flutter app using advance_image_picker plugin Call once inside application before using image picker functions
Enums
- DoneButtonDisabledBehavior
- Enum used to define the type of of behavior the done button has when no images have been selected that will be returned.
- DoneButtonStyle
- Enum used to define the type of used done button by the image picker.
- FlashMode
- The possible flash modes that can be set for a camera