ImageObject class

Image object using inside this package.

Constructors

ImageObject({required String originalPath, required String modifiedPath, String? assetId = "", int? modifiedWidth, int? modifiedHeight, List<DetectObject>? recognitions, String? label, String? ocrText, String? ocrOriginalText})
Default constructor for the image object using inside this package.

Properties

assetId ↔ String?
Asset id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
Label
getter/setter pair
modifiedHeight ↔ int?
Output image height.
getter/setter pair
modifiedPath ↔ String
Modified image path (output image path).
getter/setter pair
modifiedWidth ↔ int?
Output image width.
getter/setter pair
ocrOriginalText ↔ String?
OCR original text
getter/setter pair
ocrText ↔ String?
OCR text
getter/setter pair
originalPath ↔ String
Original image path (input image path).
getter/setter pair
recognitions ↔ List<DetectObject>?
Detected results
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited