ImageUtils class

Image utilities class.

Constructors

ImageUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

compressResizeImage(String path, {int quality = 90, int maxWidth = 1080, int maxHeight = 1920}) → Future<File>
Compare & resize image file in path. Pass quality, maxWidth, maxHeight for output image file.
cropImage(String path, {int originX = 0, int originY = 0, required double widthPercent, required double heightPercent}) → Future<File>
Crop image file in path.
getImageInfo(ImageObject img) → Future<ImageObject>
Get image information of image object img.
getImageProperties(String path) → Future<ImageProperties>
Get image properties from image file in path, such as width, height
getTempFile(String filename) → Future<File>
Get temp file created in temporary directory of device.
isTheSameAsset(AssetEntity asset, ImageObject image) → bool
Check asset & image file is the same asset or not.